@@ -8,13 +8,14 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-05-08'; # DATE
 our $DIST = 'Regexp-Pattern-Filename-Image-WhatsApp'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our %RE;
 
 $RE{filename_image_whatsapp} = {
     summary => 'Image filename saved by WhatsApp',
     pat => qr/\AIMG-[0-9]{8}-WA[0-9]{4,}\.(?:JPG|jpg)\z/,
+    tags => ['anchored'],
     examples => [
         {str=>'foo.jpg', matches=>0, summary=>'No pattern'},
         {str=>'VID-20210922-WA0001.mp4', matches=>0, summary=>'Video, not image'},
@@ -38,7 +39,7 @@ Regexp::Pattern::Filename::Image::WhatsApp - Image filename saved by WhatsApp
 
 =head1 VERSION
 
-This document describes version 0.002 of Regexp::Pattern::Filename::Image::WhatsApp (from Perl distribution Regexp-Pattern-Filename-Image-WhatsApp), released on 2022-05-08.
+This document describes version 0.003 of Regexp::Pattern::Filename::Image::WhatsApp (from Perl distribution Regexp-Pattern-Filename-Image-WhatsApp), released on 2022-05-08.
 
 =head1 SYNOPSIS
 
@@ -62,6 +63,8 @@ Using the pattern(s) directly:
 
 =item * filename_image_whatsapp
 
+Tags: anchored
+
 Image filename saved by WhatsApp.
 
 Examples:
